summaryrefslogtreecommitdiffstats
path: root/kdesktop
diff options
context:
space:
mode:
Diffstat (limited to 'kdesktop')
-rw-r--r--kdesktop/DESIGN2
-rw-r--r--kdesktop/bgmanager.cc16
-rw-r--r--kdesktop/bgmanager.h2
-rw-r--r--kdesktop/desktop.cc10
-rw-r--r--kdesktop/init.cc2
-rw-r--r--kdesktop/init/Templates/linkFloppy.desktop4
-rw-r--r--kdesktop/kcustommenu.cc4
-rw-r--r--kdesktop/kdiconview.cc56
-rw-r--r--kdesktop/kdiconview.h2
-rw-r--r--kdesktop/kfileividesktop.cpp10
-rw-r--r--kdesktop/kfileividesktop.h4
-rw-r--r--kdesktop/krootwm.cc12
-rw-r--r--kdesktop/kshadowengine.cpp20
-rw-r--r--kdesktop/kshadowengine.h4
-rw-r--r--kdesktop/kxdglauncher.cpp6
-rw-r--r--kdesktop/lock/autologout.cc10
-rw-r--r--kdesktop/lock/autologout.h2
-rw-r--r--kdesktop/lock/infodlg.cc14
-rw-r--r--kdesktop/lock/infodlg.h4
-rw-r--r--kdesktop/lock/lockdlg.cc54
-rw-r--r--kdesktop/lock/lockdlg.h6
-rw-r--r--kdesktop/lock/lockprocess.cc22
-rw-r--r--kdesktop/lock/querydlg.cc16
-rw-r--r--kdesktop/lock/querydlg.h4
-rw-r--r--kdesktop/lockeng.cc2
-rw-r--r--kdesktop/minicli.cpp48
-rw-r--r--kdesktop/minicli.h2
-rw-r--r--kdesktop/minicli_ui.ui32
-rw-r--r--kdesktop/pixmapserver.cc4
-rw-r--r--kdesktop/programs/xplanet.desktop4
-rw-r--r--kdesktop/startupid.cpp12
-rw-r--r--kdesktop/xautolock.cc2
-rw-r--r--kdesktop/xautolock_diy.c16
-rw-r--r--kdesktop/xautolock_engine.c18
34 files changed, 213 insertions, 213 deletions
diff --git a/kdesktop/DESIGN b/kdesktop/DESIGN
index ca2d6fb46..e2a6a2b8b 100644
--- a/kdesktop/DESIGN
+++ b/kdesktop/DESIGN
@@ -74,7 +74,7 @@ Multiple monitors
Two monitors showing different things (not a mirror-setup) can be configured
in X to either use one X screen, or 2 X screens. Difference is that if I
drag a window from one monitor to the other the application gets asked to
-tqrepaint itself on a 2 screen setup and a simple move of the window will be
+repaint itself on a 2 screen setup and a simple move of the window will be
done in memory (by XFree) if you have a 1 screen setup.
Monitors example:
diff --git a/kdesktop/bgmanager.h b/kdesktop/bgmanager.h
index 2923fd1b5..5b9bf70f1 100644
--- a/kdesktop/bgmanager.h
+++ b/kdesktop/bgmanager.h
@@ -84,7 +84,7 @@ private slots:
void slotChangeDesktop(int);
void slotChangeViewport(int, const TQPoint&);
void slotChangeNumberOfDesktops(int);
- void tqrepaintBackground();
+ void repaintBackground();
void desktopResized();
void clearRoot();
void saveImages();
diff --git a/kdesktop/desktop.cc b/kdesktop/desktop.cc
index 2a35eacd0..f923d953d 100644
--- a/kdesktop/desktop.cc
+++ b/kdesktop/desktop.cc
@@ -159,7 +159,7 @@ KDesktop::KDesktop( bool x_root_hack, bool wait_for_kded ) :
kapp->dcopClient()->connectDCOPSignal(kicker_name, kicker_name, "desktopIconsAreaChanged(TQRect, int)",
"KDesktopIface", "desktopIconsAreaChanged(TQRect, int)", false);
- // Dont tqrepaint on configuration changes during construction
+ // Dont repaint on configuration changes during construction
m_bInit = true;
// It's the child widget that gets the focus, not us
@@ -179,7 +179,7 @@ KDesktop::KDesktop( bool x_root_hack, bool wait_for_kded ) :
}
- setGeometry( TQApplication::desktop()->tqgeometry() );
+ setGeometry( TQApplication::desktop()->geometry() );
lower();
connect( kapp, TQT_SIGNAL( shutDown() ),
@@ -230,7 +230,7 @@ KDesktop::initRoot()
TQToolTip::add( &w, "foo" );
}
// NOTE: If mouse clicks stop working again, it's most probably something doing XSelectInput()
- // on the root window after this, and setting it to some fixed value instead of adding its tqmask.
+ // on the root window after this, and setting it to some fixed value instead of adding its mask.
XWindowAttributes attrs;
XGetWindowAttributes(dpy, root, &attrs);
XSelectInput(dpy, root, attrs.your_event_mask | ButtonPressMask);
@@ -279,7 +279,7 @@ KDesktop::initRoot()
m_pIconView->viewport()->setBackgroundMode( X11ParentRelative );
m_pIconView->setFocusPolicy( StrongFocus );
m_pIconView->viewport()->setFocusPolicy( StrongFocus );
- m_pIconView->setGeometry( tqgeometry() );
+ m_pIconView->setGeometry( geometry() );
m_pIconView->show();
// Geert Jansen: backgroundmanager belongs here
@@ -1168,7 +1168,7 @@ void KDesktop::addIcon(const TQString & _url, const TQString & _dest, int x, int
i.uDest = KURL::fromPathOrURL( _dest );
i.uDest.addPath( filename );
files.append(i);
- if (!TQFile::exists(i.uDest.prettyURL().tqreplace("file://",TQString::null))) { m_pIconView->slotAboutToCreate( TQPoint( x, y ), files );
+ if (!TQFile::exists(i.uDest.prettyURL().replace("file://",TQString::null))) { m_pIconView->slotAboutToCreate( TQPoint( x, y ), files );
KIO::copy( i.uSource, i.uDest, false ); }
// m_pIconView->addFuturePosition(filename, x, y);
diff --git a/kdesktop/init.cc b/kdesktop/init.cc
index 1d4411ce6..27441b170 100644
--- a/kdesktop/init.cc
+++ b/kdesktop/init.cc
@@ -123,7 +123,7 @@ static TQString realDesktopPath()
if (kdesktop_screen_number != 0) {
TQString dn = "Desktop";
dn += TQString::number(kdesktop_screen_number);
- desktopPath.tqreplace("Desktop", dn);
+ desktopPath.replace("Desktop", dn);
}
return desktopPath;
}
diff --git a/kdesktop/init/Templates/linkFloppy.desktop b/kdesktop/init/Templates/linkFloppy.desktop
index 6e18b2888..2a86dd575 100644
--- a/kdesktop/init/Templates/linkFloppy.desktop
+++ b/kdesktop/init/Templates/linkFloppy.desktop
@@ -53,7 +53,7 @@ Name[pt_BR]=Dispositivo de disquete...
Name[ro]=Dispozitiv Floppy...
Name[ru]=Дисковод...
Name[rw]=Apareye Disikete...
-Name[se]=Dibtqmaskearroovttadat …
+Name[se]=Dibmaskearroovttadat …
Name[sk]=Disketová mechanika...
Name[sl]=Disketna naprava ...
Name[sr]=Флопи уређај...
@@ -131,7 +131,7 @@ Comment[pt_BR]=Novo dispositivo de disquete
Comment[ro]=Dispozitiv Floppy nou
Comment[ru]=Ссылка на устройство дисковода
Comment[rw]=Apareye Disikete Nshya
-Comment[se]=Ođđa dibtqmaskearroovttadat
+Comment[se]=Ođđa dibmaskearroovttadat
Comment[sk]=Nová disketová mechanika
Comment[sl]=Nova disketna naprava
Comment[sr]=Нови флопи уређај
diff --git a/kdesktop/kdiconview.h b/kdesktop/kdiconview.h
index c9a680b4f..6afde0e4b 100644
--- a/kdesktop/kdiconview.h
+++ b/kdesktop/kdiconview.h
@@ -43,7 +43,7 @@ class KDesktopShadowSettings;
*
* Added shadow capability by Laur Ivan (C) 2003
* The shadow is supported by the new KFileIVIDesktop objects
- * which tqreplace KFileIVI objects.
+ * which replace KFileIVI objects.
*/
class KDIconView : public KonqIconViewWidget, public KDirNotify
{
diff --git a/kdesktop/kfileividesktop.cpp b/kdesktop/kfileividesktop.cpp
index 7d0f201ab..d5e367bc0 100644
--- a/kdesktop/kfileividesktop.cpp
+++ b/kdesktop/kfileividesktop.cpp
@@ -73,15 +73,15 @@ void KFileIVIDesktop::calcRect( const TQString& _text )
int spread = shadowThickness();
TQRect itemTextRect = textRect();
- TQRect tqitemRect = rect();
+ TQRect itemRect = rect();
itemTextRect.setBottom( itemTextRect.bottom() + spread );
itemTextRect.setRight( itemTextRect.right() + spread );
- tqitemRect.setBottom( tqitemRect.bottom() + spread );
- tqitemRect.setRight( tqitemRect.right() + spread );
+ itemRect.setBottom( itemRect.bottom() + spread );
+ itemRect.setRight( itemRect.right() + spread );
setTextRect( itemTextRect );
- setItemRect( tqitemRect );
+ setItemRect( itemRect );
}
void KFileIVIDesktop::paintItem( TQPainter *p, const TQColorGroup &cg)
@@ -191,7 +191,7 @@ void KFileIVIDesktop::drawShadowedText( TQPainter *p, const TQColorGroup &cg )
else {
text = settings->textColor();
shadow = ( settings->bgColor().isValid() ) ? settings->bgColor() :
- ( tqGray( text.rgb() ) > 127 ) ? black : white;
+ ( qGray( text.rgb() ) > 127 ) ? black : white;
if (rebuild) {
setNormalImage(buildShadow(p, align, shadow));
_normalUID = uid;
diff --git a/kdesktop/kfileividesktop.h b/kdesktop/kfileividesktop.h
index b0a7ff33f..129abec07 100644
--- a/kdesktop/kfileividesktop.h
+++ b/kdesktop/kfileividesktop.h
@@ -40,7 +40,7 @@ class TQFont;
class KShadowEngine;
/**
- * This class tqreplaces KFileIVI in the desktop only.
+ * This class replaces KFileIVI in the desktop only.
* If the shadow object is NULL, then the class should behave almost identical
* to its parent.
* @since 3.2
@@ -91,7 +91,7 @@ class KFileIVIDesktop : public KFileIVI
* Builds the shadow. As the algorithm is pretty slow (at pixel level),
* This method is triggered only if the configuration has changed.
* @param p the painter for drawing the item
- * @param align the shadow tqalignment
+ * @param align the shadow alignment
* @param shadowColor the shadow color
*/
virtual TQImage *buildShadow(TQPainter *p, const int align, TQColor &shadowColor);
diff --git a/kdesktop/krootwm.cc b/kdesktop/krootwm.cc
index 036061ccb..e44c027c2 100644
--- a/kdesktop/krootwm.cc
+++ b/kdesktop/krootwm.cc
@@ -243,7 +243,7 @@ void KRootWm::initConfig()
if (s == s_choices[c])
{ rightButtonChoice = (menuChoice) c; break; }
- // Read configuration for icons tqalignment
+ // Read configuration for icons alignment
if ( m_bDesktopEnabled ) {
bool startup = true; m_pDesktop->iconView()->setAutoAlign( KDesktopSettings::autoLineUpIcons() );
if ( kapp->authorize( "editable_desktop_icons" ) ) {
@@ -630,14 +630,14 @@ void KRootWm::slotWindowList() {
TQDesktopWidget* desktop = KApplication::desktop();
TQRect r;
if (desktop->numScreens() < 2)
- r = desktop->tqgeometry();
+ r = desktop->geometry();
else
r = desktop->screenGeometry( desktop->screenNumber(TQCursor::pos()));
windowListMenu->init();
disconnect( windowListMenu, TQT_SIGNAL( aboutToShow() ),
this, TQT_SLOT( slotWindowListAboutToShow() ) ); // avoid calling init() twice
- // windowListMenu->rect() is not valid before showing, use tqsizeHint()
- windowListMenu->popup(r.center() - TQRect( TQPoint( 0, 0 ), windowListMenu->tqsizeHint()).center());
+ // windowListMenu->rect() is not valid before showing, use sizeHint()
+ windowListMenu->popup(r.center() - TQRect( TQPoint( 0, 0 ), windowListMenu->sizeHint()).center());
windowListMenu->selectActiveWindow(); // make the popup more useful
connect( windowListMenu, TQT_SIGNAL( aboutToShow() ),
this, TQT_SLOT( slotWindowListAboutToShow() ) );
@@ -650,13 +650,13 @@ void KRootWm::slotSwitchUser() {
TQDesktopWidget* desktop = KApplication::desktop();
TQRect r;
if (desktop->numScreens() < 2)
- r = desktop->tqgeometry();
+ r = desktop->geometry();
else
r = desktop->screenGeometry( desktop->screenNumber(TQCursor::pos()));
slotPopulateSessions();
disconnect( sessionsMenu, TQT_SIGNAL( aboutToShow() ),
this, TQT_SLOT( slotPopulateSessions() ) ); // avoid calling init() twice
- sessionsMenu->popup(r.center() - TQRect( TQPoint( 0, 0 ), sessionsMenu->tqsizeHint()).center());
+ sessionsMenu->popup(r.center() - TQRect( TQPoint( 0, 0 ), sessionsMenu->sizeHint()).center());
connect( sessionsMenu, TQT_SIGNAL( aboutToShow() ),
TQT_SLOT( slotPopulateSessions() ) );
}
diff --git a/kdesktop/kshadowengine.cpp b/kdesktop/kshadowengine.cpp
index e8493b92b..893eac8e0 100644
--- a/kdesktop/kshadowengine.cpp
+++ b/kdesktop/kshadowengine.cpp
@@ -110,7 +110,7 @@ TQImage KShadowEngine::makeShadow(const TQPixmap& textPixmap, const TQColor &bgC
alphaShadow = (alphaShadow > m_shadowSettings->maxOpacity()) ? m_shadowSettings->maxOpacity() : alphaShadow;
// update the shadow's i,j pixel.
- result.setPixel(i,j, tqRgba(bgRed, bgGreen , bgBlue, (int) alphaShadow));
+ result.setPixel(i,j, qRgba(bgRed, bgGreen , bgBlue, (int) alphaShadow));
}
}
return result;
@@ -127,15 +127,15 @@ double KShadowEngine::defaultDecay(TQImage& source, int i, int j)
return 0;
double alphaShadow;
- alphaShadow =(tqGray(source.pixel(i-1,j-1)) * DIAGONAL_FACTOR +
- tqGray(source.pixel(i-1,j )) * AXIS_FACTOR +
- tqGray(source.pixel(i-1,j+1)) * DIAGONAL_FACTOR +
- tqGray(source.pixel(i ,j-1)) * AXIS_FACTOR +
+ alphaShadow =(qGray(source.pixel(i-1,j-1)) * DIAGONAL_FACTOR +
+ qGray(source.pixel(i-1,j )) * AXIS_FACTOR +
+ qGray(source.pixel(i-1,j+1)) * DIAGONAL_FACTOR +
+ qGray(source.pixel(i ,j-1)) * AXIS_FACTOR +
0 +
- tqGray(source.pixel(i ,j+1)) * AXIS_FACTOR +
- tqGray(source.pixel(i+1,j-1)) * DIAGONAL_FACTOR +
- tqGray(source.pixel(i+1,j )) * AXIS_FACTOR +
- tqGray(source.pixel(i+1,j+1)) * DIAGONAL_FACTOR) / m_shadowSettings->multiplicationFactor();
+ qGray(source.pixel(i ,j+1)) * AXIS_FACTOR +
+ qGray(source.pixel(i+1,j-1)) * DIAGONAL_FACTOR +
+ qGray(source.pixel(i+1,j )) * AXIS_FACTOR +
+ qGray(source.pixel(i+1,j+1)) * DIAGONAL_FACTOR) / m_shadowSettings->multiplicationFactor();
return alphaShadow;
}
@@ -185,7 +185,7 @@ double KShadowEngine::noDecay(TQImage& source, int i, int j)
else
sy = j + m;
- opacity += tqGray(source.pixel(sx, sy));
+ opacity += qGray(source.pixel(sx, sy));
}
}
alphaShadow += opacity / m_shadowSettings->multiplicationFactor();
diff --git a/kdesktop/kshadowengine.h b/kdesktop/kshadowengine.h
index 4a9d6b7eb..33391e464 100644
--- a/kdesktop/kshadowengine.h
+++ b/kdesktop/kshadowengine.h
@@ -92,13 +92,13 @@ class KShadowEngine
/*
* a slower algorithm where the influence of a pixel
- * is tqGray(px)/(abs(dx) + abs(dy) +1).
+ * is qGray(px)/(abs(dx) + abs(dy) +1).
*/
double doubleLinearDecay(TQImage& source, int x, int y);
/*
* a very slow algorithm where the influence of a pixel
- * is tqGray(px)/(sqrt(sqr(dx) + sqr(dy)) +1).
+ * is qGray(px)/(sqrt(sqr(dx) + sqr(dy)) +1).
*/
double radialDecay(TQImage& source, int x, int y);
diff --git a/kdesktop/kxdglauncher.cpp b/kdesktop/kxdglauncher.cpp
index 01792ad76..ff173c842 100644
--- a/kdesktop/kxdglauncher.cpp
+++ b/kdesktop/kxdglauncher.cpp
@@ -52,9 +52,9 @@ void readXdgUserDirs(TQString *desktop, TQString *documents)
while (!line.isNull())
{
if (line.startsWith("XDG_DESKTOP_DIR="))
- *desktop = line.remove("XDG_DESKTOP_DIR=").remove("\"").tqreplace("$HOME", TQDir::homeDirPath());
+ *desktop = line.remove("XDG_DESKTOP_DIR=").remove("\"").replace("$HOME", TQDir::homeDirPath());
else if (line.startsWith("XDG_DOCUMENTS_DIR="))
- *documents = line.remove("XDG_DOCUMENTS_DIR=").remove("\"").tqreplace("$HOME", TQDir::homeDirPath());
+ *documents = line.remove("XDG_DOCUMENTS_DIR=").remove("\"").replace("$HOME", TQDir::homeDirPath());
line = s.readLine();
}
@@ -132,7 +132,7 @@ int main( int argc, char **argv)
}
if (directoryOk == true) {
TQString xdgModifiedDirectory = newDirectory;
- xdgModifiedDirectory = xdgModifiedDirectory.tqreplace(TQDir::homeDirPath(), "$HOME");
+ xdgModifiedDirectory = xdgModifiedDirectory.replace(TQDir::homeDirPath(), "$HOME");
while (xdgModifiedDirectory.endsWith("/")) {
xdgModifiedDirectory.truncate(xdgModifiedDirectory.length()-1);
}
diff --git a/kdesktop/lock/autologout.cc b/kdesktop/lock/autologout.cc
index 79a59787b..b51791d98 100644
--- a/kdesktop/lock/autologout.cc
+++ b/kdesktop/lock/autologout.cc
@@ -39,8 +39,8 @@ AutoLogout::AutoLogout(LockProcess *parent) : TQDialog(parent, "password dialog"
TQLabel *greetLabel = new TQLabel(i18n("<nobr><qt><b>Automatic Log Out</b></qt><nobr>"), frame);
TQLabel *infoLabel = new TQLabel(i18n("<qt>To prevent being logged out, resume using this session by moving the mouse or pressing a key.</qt>"), frame);
- mtqStatusLabel = new TQLabel("<b> </b>", frame);
- mtqStatusLabel->tqsetAlignment(TQLabel::AlignCenter);
+ mStatusLabel = new TQLabel("<b> </b>", frame);
+ mStatusLabel->setAlignment(TQLabel::AlignCenter);
TQLabel *mProgressLabel = new TQLabel("Time Remaining:", frame);
mProgressRemaining = new TQProgressBar(frame);
@@ -52,7 +52,7 @@ AutoLogout::AutoLogout(LockProcess *parent) : TQDialog(parent, "password dialog"
frameLayout = new TQGridLayout(frame, 1, 1, KDialog::marginHint(), KDialog::spacingHint());
frameLayout->addMultiCellWidget(pixLabel, 0, 2, 0, 0, Qt::AlignCenter | Qt::AlignTop);
frameLayout->addWidget(greetLabel, 0, 1);
- frameLayout->addWidget(mtqStatusLabel, 1, 1);
+ frameLayout->addWidget(mStatusLabel, 1, 1);
frameLayout->addWidget(infoLabel, 2, 1);
frameLayout->addWidget(mProgressLabel, 3, 1);
frameLayout->addWidget(mProgressRemaining, 4, 1);
@@ -66,7 +66,7 @@ AutoLogout::AutoLogout(LockProcess *parent) : TQDialog(parent, "password dialog"
mCountdownTimerId = startTimer(1000/25);
- connect(tqApp, TQT_SIGNAL(activity()), TQT_SLOT(slotActivity()));
+ connect(qApp, TQT_SIGNAL(activity()), TQT_SLOT(slotActivity()));
}
AutoLogout::~AutoLogout()
@@ -76,7 +76,7 @@ AutoLogout::~AutoLogout()
void AutoLogout::updateInfo(int timeout)
{
- mtqStatusLabel->setText(i18n("<nobr><qt>You will be automatically logged out in 1 second</qt></nobr>",
+ mStatusLabel->setText(i18n("<nobr><qt>You will be automatically logged out in 1 second</qt></nobr>",
"<nobr><qt>You will be automatically logged out in %n seconds</qt></nobr>",
timeout / 25) );
mProgressRemaining->setProgress(timeout);
diff --git a/kdesktop/lock/autologout.h b/kdesktop/lock/autologout.h
index 355ac8635..f40ac5f0d 100644
--- a/kdesktop/lock/autologout.h
+++ b/kdesktop/lock/autologout.h
@@ -39,7 +39,7 @@ private:
void updateInfo(int);
TQFrame *frame;
TQGridLayout *frameLayout;
- TQLabel *mtqStatusLabel;
+ TQLabel *mStatusLabel;
int mCountdownTimerId;
int mRemaining;
TQTimer countDownTimer;
diff --git a/kdesktop/lock/infodlg.cc b/kdesktop/lock/infodlg.cc
index 460c8d590..2249dc46e 100644
--- a/kdesktop/lock/infodlg.cc
+++ b/kdesktop/lock/infodlg.cc
@@ -71,18 +71,18 @@ InfoDlg::InfoDlg(LockProcess *parent)
KUser user;
- mtqStatusLabel = new TQLabel( "<b> </b>", frame );
- mtqStatusLabel->tqsetAlignment( TQLabel::AlignCenter );
+ mStatusLabel = new TQLabel( "<b> </b>", frame );
+ mStatusLabel->setAlignment( TQLabel::AlignCenter );
TQVBoxLayout *unlockDialogLayout = new TQVBoxLayout( this );
unlockDialogLayout->addWidget( frame );
- TQHBoxLayout *laytqStatus = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
- laytqStatus->addWidget( mtqStatusLabel );
+ TQHBoxLayout *layStatus = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
+ layStatus->addWidget( mStatusLabel );
frameLayout = new TQGridLayout( frame, 1, 1, KDialog::marginHint(), KDialog::spacingHint() );
frameLayout->addMultiCellWidget( mpixLabel, 0, 2, 0, 0, AlignTop );
- frameLayout->addLayout( laytqStatus, 1, 1 );
+ frameLayout->addLayout( layStatus, 1, 1 );
installEventFilter(this);
}
@@ -94,8 +94,8 @@ InfoDlg::~InfoDlg()
void InfoDlg::updateLabel(TQString &txt)
{
- mtqStatusLabel->setPaletteForegroundColor(Qt::black);
- mtqStatusLabel->setText("<b>" + txt + "</b>");
+ mStatusLabel->setPaletteForegroundColor(Qt::black);
+ mStatusLabel->setText("<b>" + txt + "</b>");
}
void InfoDlg::setUnlockIcon()
diff --git a/kdesktop/lock/infodlg.h b/kdesktop/lock/infodlg.h
index 687a7c28a..a0ca3b8c0 100644
--- a/kdesktop/lock/infodlg.h
+++ b/kdesktop/lock/infodlg.h
@@ -43,11 +43,11 @@ public:
private:
TQFrame *frame;
TQGridLayout *frameLayout;
- TQLabel *mtqStatusLabel;
+ TQLabel *mStatusLabel;
TQLabel *mpixLabel;
int mCapsLocked;
bool mUnlockingFailed;
- TQStringList tqlayoutsList;
+ TQStringList layoutsList;
TQStringList::iterator currLayout;
int sPid, sFd;
};
diff --git a/kdesktop/lock/lockdlg.cc b/kdesktop/lock/lockdlg.cc
index 67c2a063e..2efe56a8a 100644
--- a/kdesktop/lock/lockdlg.cc
+++ b/kdesktop/lock/lockdlg.cc
@@ -82,8 +82,8 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
i18n("<nobr><b>The session is locked</b><br>") :
i18n("<nobr><b>The session was locked by %1</b><br>").arg( user.fullName() ), frame );
- mtqStatusLabel = new TQLabel( "<b> </b>", frame );
- mtqStatusLabel->tqsetAlignment( TQLabel::AlignCenter );
+ mStatusLabel = new TQLabel( "<b> </b>", frame );
+ mStatusLabel->setAlignment( TQLabel::AlignCenter );
mLayoutButton = new TQPushButton( frame );
mLayoutButton->setFlat( true );
@@ -101,9 +101,9 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
TQVBoxLayout *unlockDialogLayout = new TQVBoxLayout( this );
unlockDialogLayout->addWidget( frame );
- TQHBoxLayout *laytqStatus = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
- laytqStatus->addWidget( mtqStatusLabel );
- laytqStatus->addWidget( mLayoutButton );
+ TQHBoxLayout *layStatus = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
+ layStatus->addWidget( mStatusLabel );
+ layStatus->addWidget( mLayoutButton );
TQHBoxLayout *layButtons = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
layButtons->addWidget( mNewSessButton );
@@ -115,7 +115,7 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
frameLayout->addMultiCellWidget( pixLabel, 0, 2, 0, 0, AlignTop );
frameLayout->addWidget( greetLabel, 0, 1 );
frameLayout->addItem( greet->getLayoutItem(), 1, 1 );
- frameLayout->addLayout( laytqStatus, 2, 1 );
+ frameLayout->addLayout( layStatus, 2, 1 );
frameLayout->addMultiCellWidget( sep, 3, 3, 0, 1 );
frameLayout->addMultiCellLayout( layButtons, 4, 4, 0, 1 );
@@ -123,7 +123,7 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
setTabOrder( cancel, mNewSessButton );
setTabOrder( mNewSessButton, mLayoutButton );
- connect(mLayoutButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(tqlayoutClicked()));
+ connect(mLayoutButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(layoutClicked()));
connect(cancel, TQT_SIGNAL(clicked()), TQT_SLOT(reject()));
connect(ok, TQT_SIGNAL(clicked()), TQT_SLOT(slotOK()));
connect(mNewSessButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotSwitchUser()));
@@ -135,17 +135,17 @@ PasswordDlg::PasswordDlg(LockProcess *parent, GreeterPluginHandle *plugin)
mFailedTimerId = 0;
mTimeoutTimerId = startTimer(PASSDLG_HIDE_TIMEOUT);
- connect(tqApp, TQT_SIGNAL(activity()), TQT_SLOT(slotActivity()) );
+ connect(qApp, TQT_SIGNAL(activity()), TQT_SLOT(slotActivity()) );
greet->start();
DCOPRef kxkb("kxkb", "kxkb");
if( !kxkb.isNull() ) {
- tqlayoutsList = kxkb.call("getLayoutsList");
+ layoutsList = kxkb.call("getLayoutsList");
TQString currentLayout = kxkb.call("getCurrentLayout");
- if( !currentLayout.isEmpty() && tqlayoutsList.count() > 1 ) {
- currLayout = tqlayoutsList.find(currentLayout);
- if (currLayout == tqlayoutsList.end())
+ if( !currentLayout.isEmpty() && layoutsList.count() > 1 ) {
+ currLayout = layoutsList.find(currentLayout);
+ if (currLayout == layoutsList.end())
setLayoutText("err");
else
setLayoutText(*currLayout);
@@ -164,11 +164,11 @@ PasswordDlg::~PasswordDlg()
delete greet;
}
-void PasswordDlg::tqlayoutClicked()
+void PasswordDlg::layoutClicked()
{
- if( ++currLayout == tqlayoutsList.end() )
- currLayout = tqlayoutsList.begin();
+ if( ++currLayout == layoutsList.end() )
+ currLayout = layoutsList.begin();
DCOPRef kxkb("kxkb", "kxkb");
setLayoutText( kxkb.call("setLayout", *currLayout) ? *currLayout : "err" );
@@ -179,7 +179,7 @@ void PasswordDlg::setLayoutText( const TQString &txt )
{
mLayoutButton->setText( txt );
TQSize sz = mLayoutButton->fontMetrics().size( 0, txt );
- int mrg = mLayoutButton->style().tqpixelMetric( TQStyle::PM_ButtonMargin ) * 2;
+ int mrg = mLayoutButton->style().pixelMetric( TQStyle::PM_ButtonMargin ) * 2;
mLayoutButton->setFixedSize( sz.width() + mrg, sz.height() + mrg );
}
@@ -187,18 +187,18 @@ void PasswordDlg::updateLabel()
{
if (mUnlockingFailed)
{
- mtqStatusLabel->setPaletteForegroundColor(Qt::black);
- mtqStatusLabel->setText(i18n("<b>Unlocking failed</b>"));
+ mStatusLabel->setPaletteForegroundColor(Qt::black);
+ mStatusLabel->setText(i18n("<b>Unlocking failed</b>"));
}
else
if (mCapsLocked)
{
- mtqStatusLabel->setPaletteForegroundColor(Qt::red);
- mtqStatusLabel->setText(i18n("<b>Warning: Caps Lock on</b>"));
+ mStatusLabel->setPaletteForegroundColor(Qt::red);
+ mStatusLabel->setText(i18n("<b>Warning: Caps Lock on</b>"));
}
else
{
- mtqStatusLabel->setText("<b> </b>");
+ mStatusLabel->setText("<b> </b>");
}
}
@@ -480,7 +480,7 @@ void PasswordDlg::gplugMsgBox( TQMessageBox::Icon type, const TQString &text )
TQLabel *label2 = new TQLabel( text, winFrame );
KPushButton *button = new KPushButton( KStdGuiItem::ok(), winFrame );
button->setDefault( true );
- button->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Preferred ) );
+ button->setSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Preferred ) );
connect( button, TQT_SIGNAL( clicked() ), TQT_SLOT( accept() ) );
TQGridLayout *grid = new TQGridLayout( winFrame, 2, 2, 10 );
@@ -667,9 +667,9 @@ void PasswordDlg::slotSwitchUser()
ns++;
}
int fw = lv->frameWidth() * 2;
- TQSize hds( lv->header()->tqsizeHint() );
+ TQSize hds( lv->header()->sizeHint() );
lv->setMinimumWidth( fw + hds.width() +
- (ns > 10 ? style().tqpixelMetric(TQStyle::PM_ScrollBarExtent) : 0 ) );
+ (ns > 10 ? style().pixelMetric(TQStyle::PM_ScrollBarExtent) : 0 ) );
lv->setFixedHeight( fw + hds.height() +
itm->height() * (ns < 6 ? 6 : ns > 10 ? 10 : ns) );
lv->header()->adjustHeaderSize();
@@ -709,11 +709,11 @@ void PasswordDlg::slotSessionActivated()
void PasswordDlg::capsLocked()
{
- unsigned int ltqmask;
+ unsigned int lmask;
Window dummy1, dummy2;
int dummy3, dummy4, dummy5, dummy6;
- XQueryPointer(qt_xdisplay(), DefaultRootWindow( qt_xdisplay() ), &dummy1, &dummy2, &dummy3, &dummy4, &dummy5, &dummy6, &ltqmask);
- mCapsLocked = ltqmask & LockMask;
+ XQueryPointer(qt_xdisplay(), DefaultRootWindow( qt_xdisplay() ), &dummy1, &dummy2, &dummy3, &dummy4, &dummy5, &dummy6, &lmask);
+ mCapsLocked = lmask & LockMask;
updateLabel();
}
diff --git a/kdesktop/lock/lockdlg.h b/kdesktop/lock/lockdlg.h
index fa506ee50..258339314 100644
--- a/kdesktop/lock/lockdlg.h
+++ b/kdesktop/lock/lockdlg.h
@@ -55,7 +55,7 @@ private slots:
void slotSessionActivated();
void slotStartNewSession();
void slotOK();
- void tqlayoutClicked();
+ void layoutClicked();
void slotActivity();
private:
@@ -77,14 +77,14 @@ private:
KGreeterPlugin *greet;
TQFrame *frame;
TQGridLayout *frameLayout;
- TQLabel *mtqStatusLabel;
+ TQLabel *mStatusLabel;
KPushButton *mNewSessButton, *ok, *cancel;
TQPushButton *mLayoutButton;
int mFailedTimerId;
int mTimeoutTimerId;
int mCapsLocked;
bool mUnlockingFailed;
- TQStringList tqlayoutsList;
+ TQStringList layoutsList;
TQStringList::iterator currLayout;
int sPid, sFd;
TQListView *lv;
diff --git a/kdesktop/lock/lockprocess.cc b/kdesktop/lock/lockprocess.cc
index 3d264a08c..cdd5581e7 100644
--- a/kdesktop/lock/lockprocess.cc
+++ b/kdesktop/lock/lockprocess.cc
@@ -88,7 +88,7 @@ extern "C" {
#include <X11/extensions/dpms.h>
#ifndef HAVE_DPMSINFO_PROTO
-tqStatus DPMSInfo ( Display *, CARD16 *, BOOL * );
+Status DPMSInfo ( Display *, CARD16 *, BOOL * );
#endif
}
#endif
@@ -195,7 +195,7 @@ LockProcess::LockProcess(bool child, bool useBlankOnly)
TQStringList dmopt =
TQStringList::split(TQChar(','),
- TQString::tqfromLatin1( ::getenv( "XDM_MANAGED" )));
+ TQString::fromLatin1( ::getenv( "XDM_MANAGED" )));
for (TQStringList::ConstIterator it = dmopt.begin(); it != dmopt.end(); ++it)
if ((*it).startsWith("method="))
mMethod = (*it).mid(7);
@@ -944,7 +944,7 @@ void LockProcess::stopSaver()
TQVariant LockProcess::getConf(void *ctx, const char *key, const TQVariant &dflt)
{
LockProcess *that = (LockProcess *)ctx;
- TQString fkey = TQString::tqfromLatin1( key ) + '=';
+ TQString fkey = TQString::fromLatin1( key ) + '=';
for (TQStringList::ConstIterator it = that->mPluginOptions.begin();
it != that->mPluginOptions.end(); ++it)
if ((*it).startsWith( fkey ))
@@ -1174,7 +1174,7 @@ int LockProcess::execDialog( TQDialog *dlg )
currentDialog=dlg;
dlg->adjustSize();
- TQRect rect = dlg->tqgeometry();
+ TQRect rect = dlg->geometry();
rect.moveCenter(KGlobalSettings::desktopGeometry(TQCursor::pos()).center());
dlg->move( rect.topLeft() );
@@ -1341,7 +1341,7 @@ bool LockProcess::x11Event(XEvent *event)
{
XEvent ev2 = *event;
ev2.xkey.window = ev2.xkey.subwindow = mDialogs.first()->winId();
- tqApp->x11ProcessEvent( &ev2 );
+ qApp->x11ProcessEvent( &ev2 );
return true;
}
@@ -1453,7 +1453,7 @@ void LockProcess::msgBox( TQMessageBox::Icon type, const TQString &txt )
TQLabel *label2 = new TQLabel( txt, winFrame );
KPushButton *button = new KPushButton( KStdGuiItem::ok(), winFrame );
button->setDefault( true );
- button->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Preferred ) );
+ button->setSizePolicy( TQSizePolicy( TQSizePolicy::Preferred, TQSizePolicy::Preferred ) );
connect( button, TQT_SIGNAL( clicked() ), &box, TQT_SLOT( accept() ) );
TQVBoxLayout *vbox = new TQVBoxLayout( &box );
@@ -1481,7 +1481,7 @@ void LockProcess::showVkbd()
mKWinModule = new KWinModule( NULL, KWinModule::INFO_WINDOWS );
connect( mKWinModule, TQT_SIGNAL( windowAdded( WId )), TQT_SLOT( windowAdded( WId )));
mVkbdProcess = new KProcess;
- *mVkbdProcess << "xvkbd" << "-compact" << "-tqgeometry" << "-0-0" << "-xdm";
+ *mVkbdProcess << "xvkbd" << "-compact" << "-geometry" << "-0-0" << "-xdm";
mVkbdProcess->start();
}
}
@@ -1525,7 +1525,7 @@ void LockProcess::windowAdded( WId w, bool managed )
&length, &after, &data );
bool withdrawn = true;
if ( r == Success && data && format == 32 ) {
- TQ_UINT32 *wstate = (TQ_UINT32*)data;
+ Q_UINT32 *wstate = (Q_UINT32*)data;
withdrawn = (*wstate == WithdrawnState );
XFree( (char *)data );
}
@@ -1576,15 +1576,15 @@ bool LockProcess::forwardVkbdEvent( XEvent* event )
for( TQValueList< VkbdWindow >::ConstIterator it = mVkbdWindows.begin();
it != mVkbdWindows.end();
++it ) {
- if( (*it).rect.tqcontains( pos )) {
+ if( (*it).rect.contains( pos )) {
// Find the subwindow where the event should actually go.
// Not exactly cheap in the number of X roundtrips but oh well.
Window window = (*it).id;
Window root, child;
int root_x, root_y, x, y;
- unsigned int tqmask;
+ unsigned int mask;
for(;;) {
- if( !XQueryPointer( qt_xdisplay(), window, &root, &child, &root_x, &root_y, &x, &y, &tqmask ))
+ if( !XQueryPointer( qt_xdisplay(), window, &root, &child, &root_x, &root_y, &x, &y, &mask ))
return false;
if( child == None )
break;
diff --git a/kdesktop/lock/querydlg.cc b/kdesktop/lock/querydlg.cc
index ea1d1bc06..d4ad06e88 100644
--- a/kdesktop/lock/querydlg.cc
+++ b/kdesktop/lock/querydlg.cc
@@ -71,9 +71,9 @@ QueryDlg::QueryDlg(LockProcess *parent)
KUser user;
- mtqStatusLabel = new TQLabel( "<b> </b>", frame );
- //mtqStatusLabel->tqsetAlignment( TQLabel::AlignCenter );
- mtqStatusLabel->tqsetAlignment( TQLabel::AlignLeft );
+ mStatusLabel = new TQLabel( "<b> </b>", frame );
+ //mStatusLabel->setAlignment( TQLabel::AlignCenter );
+ mStatusLabel->setAlignment( TQLabel::AlignLeft );
KSeparator *sep = new KSeparator( KSeparator::HLine, frame );
@@ -82,8 +82,8 @@ QueryDlg::QueryDlg(LockProcess *parent)
TQVBoxLayout *unlockDialogLayout = new TQVBoxLayout( this );
unlockDialogLayout->addWidget( frame );
- TQHBoxLayout *laytqStatus = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
- laytqStatus->addWidget( mtqStatusLabel );
+ TQHBoxLayout *layStatus = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
+ layStatus->addWidget( mStatusLabel );
TQHBoxLayout *layPin = new TQHBoxLayout( 0, 0, KDialog::spacingHint());
pin_box = new KPasswordEdit( this, "pin_box" );
@@ -96,7 +96,7 @@ QueryDlg::QueryDlg(LockProcess *parent)
frameLayout = new TQGridLayout( frame, 1, 1, KDialog::marginHint(), KDialog::spacingHint() );
frameLayout->addMultiCellWidget( mpixLabel, 0, 2, 0, 0, AlignTop );
- frameLayout->addLayout( laytqStatus, 0, 1 );
+ frameLayout->addLayout( layStatus, 0, 1 );
frameLayout->addLayout( layPin, 2, 1 );
frameLayout->addMultiCellWidget( sep, 3, 3, 0, 1 );
frameLayout->addMultiCellLayout( layButtons, 4, 4, 0, 1 );
@@ -123,8 +123,8 @@ const char * QueryDlg::getEntry()
void QueryDlg::updateLabel(TQString &txt)
{
- mtqStatusLabel->setPaletteForegroundColor(Qt::black);
- mtqStatusLabel->setText("<b>" + txt + "</b>");
+ mStatusLabel->setPaletteForegroundColor(Qt::black);
+ mStatusLabel->setText("<b>" + txt + "</b>");
}
void QueryDlg::setUnlockIcon()
diff --git a/kdesktop/lock/querydlg.h b/kdesktop/lock/querydlg.h
index 698d7805d..e6a768369 100644
--- a/kdesktop/lock/querydlg.h
+++ b/kdesktop/lock/querydlg.h
@@ -46,11 +46,11 @@ private slots:
private:
TQFrame *frame;
TQGridLayout *frameLayout;
- TQLabel *mtqStatusLabel;
+ TQLabel *mStatusLabel;
TQLabel *mpixLabel;
int mCapsLocked;
bool mUnlockingFailed;
- TQStringList tqlayoutsList;
+ TQStringList layoutsList;
TQStringList::iterator currLayout;
int sPid, sFd;
KPushButton *ok;
diff --git a/kdesktop/lockeng.cc b/kdesktop/lockeng.cc
index 601efb1c4..43c39f19f 100644
--- a/kdesktop/lockeng.cc
+++ b/kdesktop/lockeng.cc
@@ -157,7 +157,7 @@ bool SaverEngine::enable( bool e )
}
mXAutoLock->setTimeout(mTimeout);
mXAutoLock->setDPMS(true);
- //mXAutoLock->changeCornerLocktqStatus( mLockCornerTopLeft, mLockCornerTopRight, mLockCornerBottomLeft, mLockCornerBottomRight);
+ //mXAutoLock->changeCornerLockStatus( mLockCornerTopLeft, mLockCornerTopRight, mLockCornerBottomLeft, mLockCornerBottomRight);
// We'll handle blanking
XSetScreenSaver(qt_xdisplay(), mTimeout + 10, mXInterval, PreferBlanking, mXExposures);
diff --git a/kdesktop/minicli.cpp b/kdesktop/minicli.cpp
index c036a4306..027aa0bfc 100644
--- a/kdesktop/minicli.cpp
+++ b/kdesktop/minicli.cpp
@@ -89,7 +89,7 @@ Minicli::Minicli( TQWidget *parent, const char *name)
mainLayout->addWidget(m_dlg);
m_dlg->lbRunIcon->setPixmap(DesktopIcon("kmenu"));
- m_dlg->lbComment->tqsetAlignment( Qt::WordBreak );
+ m_dlg->lbComment->setAlignment( Qt::WordBreak );
m_dlg->cbCommand->setDuplicatesEnabled( false );
m_dlg->cbCommand->setTrapReturnKey( true );
@@ -179,9 +179,9 @@ void Minicli::setCommand(const TQString& command)
}
}
-TQSize Minicli::tqsizeHint() const
+TQSize Minicli::sizeHint() const
{
- int maxWidth = tqApp->desktop()->screenGeometry((TQWidget*)this).width();
+ int maxWidth = qApp->desktop()->screenGeometry((TQWidget*)this).width();
if (maxWidth < 603)
{
// a sensible max for smaller screens
@@ -389,7 +389,7 @@ TQString Minicli::terminalCommand (const TQString& cmd, const TQString& args)
else
terminal += TQString(" -e /bin/sh -c \"%1 %2\"").arg(cmd).arg(args);
- if (!m_terminalAppList.tqcontains(cmd))
+ if (!m_terminalAppList.contains(cmd))
m_terminalAppList << cmd;
return terminal;
@@ -414,13 +414,13 @@ int Minicli::runCommand()
cmd = uri.url();
TQCString asn;
- if( tqApp->desktop()->isVirtualDesktop())
+ if( qApp->desktop()->isVirtualDesktop())
{
asn = KStartupInfo::createNewStartupId();
KStartupInfoId id;
id.initId( asn );
KStartupInfoData data;
- data.setXinerama( tqApp->desktop()->screenNumber( this ));
+ data.setXinerama( qApp->desktop()->screenNumber( this ));
KStartupInfo::sendChange( id, data );
}
@@ -558,7 +558,7 @@ int Minicli::runCommand()
case KURIFilterData::HELP:
{
// No need for kfmclient, KRun does it all (David)
- (void) new KRun( m_filterData->uri(), tqparentWidget(), asn );
+ (void) new KRun( m_filterData->uri(), parentWidget(), asn );
return 0;
}
case KURIFilterData::EXECUTABLE:
@@ -570,7 +570,7 @@ int Minicli::runCommand()
if (service && service->isValid() && service->type() == "Application")
{
notifyServiceStarted(service);
- KRun::run(*service, KURL::List(), tqparentWidget(), asn );
+ KRun::run(*service, KURL::List(), parentWidget(), asn );
return 0;
}
}
@@ -605,7 +605,7 @@ int Minicli::runCommand()
if (service && service->isValid() && service->type() == "Application")
{
notifyServiceStarted(service);
- KRun::run(*service, KURL::List(), tqparentWidget(), asn );
+ KRun::run(*service, KURL::List(), parentWidget(), asn );
return 0;
}
@@ -613,7 +613,7 @@ int Minicli::runCommand()
if (service && service->isValid() && service->type() == "Application")
{
notifyServiceStarted(service);
- KRun::run(*service, KURL::List(), tqparentWidget(), asn );
+ KRun::run(*service, KURL::List(), parentWidget(), asn );
return 0;
}
@@ -625,7 +625,7 @@ int Minicli::runCommand()
}
}
- if ( KRun::runCommand( cmd, exec, m_iconName, tqparentWidget(), asn ) )
+ if ( KRun::runCommand( cmd, exec, m_iconName, parentWidget(), asn ) )
return 0;
else
{
@@ -674,7 +674,7 @@ void Minicli::slotCmdChanged(const TQString& text)
// Also use autocompletion if it appears that I am using some kind of ioslave, except the http:// ioslave
m_urlCompletionStarted = true; // flag for slotMatch()
- if ((text.startsWith( "/" ) || text.startsWith( "~" ) || (text.tqcontains("://", false) != 0)) && (text.tqcontains("http://", false) == 0)) {
+ if ((text.startsWith( "/" ) || text.startsWith( "~" ) || (text.contains("://", false) != 0)) && (text.contains("http://", false) == 0)) {
TQString completion = m_pURLCompletion->makeCompletion( text );
}
}
@@ -730,7 +730,7 @@ void Minicli::slotAdvanced()
// Set the focus back to the widget that had it to begin with, i.e.
// do not put the focus on the "Options" button.
- m_FocusWidget = tqfocusWidget();
+ m_FocusWidget = focusWidget();
if( m_FocusWidget )
m_FocusWidget->setFocus();
@@ -763,7 +763,7 @@ void Minicli::parseLine( bool final )
KURIFilter::self()->filterURI( *(m_filterData), m_middleFilters );
bool isTerminalApp = ((m_filterData->uriType() == KURIFilterData::EXECUTABLE) &&
- m_terminalAppList.tqcontains(m_filterData->uri().url()));
+ m_terminalAppList.contains(m_filterData->uri().url()));
if( !isTerminalApp )
{
@@ -792,7 +792,7 @@ void Minicli::parseLine( bool final )
void Minicli::setIcon ()
{
if( m_iconName.isEmpty() || m_iconName == "unknown" || m_iconName == "kde" )
- m_iconName = TQString::tqfromLatin1("kmenu");
+ m_iconName = TQString::fromLatin1("kmenu");
TQPixmap icon = DesktopIcon( m_iconName );
@@ -806,14 +806,14 @@ void Minicli::setIcon ()
{
int x = icon.width() - overlay.width();
int y = icon.height() - overlay.height();
- if ( icon.tqmask() )
+ if ( icon.mask() )
{
- TQBitmap tqmask = *icon.tqmask();
- bitBlt( &tqmask, x, y,
- overlay.tqmask() ? const_cast<TQBitmap *>(overlay.tqmask()) : &overlay,
+ TQBitmap mask = *icon.mask();
+ bitBlt( &mask, x, y,
+ overlay.mask() ? const_cast<TQBitmap *>(overlay.mask()) : &overlay,
0, 0, overlay.width(), overlay.height(),
- overlay.tqmask() ? OrROP : SetROP );
- icon.setMask(tqmask);
+ overlay.mask() ? OrROP : SetROP );
+ icon.setMask(mask);
}
bitBlt( &icon, x, y, &overlay );
}
@@ -837,9 +837,9 @@ void Minicli::updateAuthLabel()
m_prevChecked = m_dlg->cbRunAsOther->isChecked();
m_prevCached = true;
}
- if (m_dlg->leUsername->text() != TQString::tqfromLatin1("root"))
+ if (m_dlg->leUsername->text() != TQString::fromLatin1("root"))
m_dlg->lePassword->setText(TQString::null);
- m_dlg->leUsername->setText(TQString::tqfromLatin1("root"));
+ m_dlg->leUsername->setText(TQString::fromLatin1("root"));
m_dlg->cbRunAsOther->setChecked(true);
m_dlg->cbRunAsOther->setEnabled(false);
m_dlg->leUsername->setEnabled(false);
@@ -884,7 +884,7 @@ void Minicli::slotTerminal(bool enable)
if (enable)
{
m_prevIconName = m_iconName;
- m_iconName = TQString::tqfromLatin1( "konsole" );
+ m_iconName = TQString::fromLatin1( "konsole" );
setIcon();
}
else if (!m_prevIconName.isEmpty())
diff --git a/kdesktop/minicli.h b/kdesktop/minicli.h
index 93c296600..4ae49cf7c 100644
--- a/kdesktop/minicli.h
+++ b/kdesktop/minicli.h
@@ -57,7 +57,7 @@ public:
void clearHistory();
virtual void show();
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
public slots:
void saveConfig();
diff --git a/kdesktop/minicli_ui.ui b/kdesktop/minicli_ui.ui
index e426a4725..3809eb852 100644
--- a/kdesktop/minicli_ui.ui
+++ b/kdesktop/minicli_ui.ui
@@ -4,7 +4,7 @@
<property name="name">
<cstring>MinicliDlgUI</cstring>
</property>
- <property name="tqgeometry">
+ <property name="geometry">
<rect>
<x>0</x>
<y>0</y>
@@ -29,7 +29,7 @@
</property>
<widget class="QLayoutWidget" row="4" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -61,7 +61,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>80</width>
<height>20</height>
@@ -107,7 +107,7 @@
</widget>
<widget class="QLayoutWidget" row="2" column="0" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout4</cstring>
+ <cstring>layout4</cstring>
</property>
<hbox>
<property name="name">
@@ -123,7 +123,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>57</width>
<height>20</height>
@@ -157,7 +157,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>30</height>
@@ -286,7 +286,7 @@
</widget>
<widget class="QLayoutWidget" row="6" column="1">
<property name="name">
- <cstring>tqlayout30</cstring>
+ <cstring>layout30</cstring>
</property>
<vbox>
<property name="name">
@@ -319,7 +319,7 @@
<property name="sizeType">
<enum>Minimum</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>9</height>
@@ -360,7 +360,7 @@
</widget>
<widget class="QLayoutWidget" row="6" column="2" rowspan="1" colspan="2">
<property name="name">
- <cstring>tqlayout29</cstring>
+ <cstring>layout29</cstring>
</property>
<grid>
<property name="name">
@@ -393,7 +393,7 @@
<property name="text">
<string>High</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignVCenter|AlignRight</set>
</property>
<property name="whatsThis" stdset="0">
@@ -448,7 +448,7 @@
<property name="sizeType">
<enum>Fixed</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>40</height>
@@ -515,7 +515,7 @@
<property name="text">
<string></string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>AlignCenter</set>
</property>
</widget>
@@ -531,7 +531,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>388</width>
<height>0</height>
@@ -556,7 +556,7 @@
<property name="text">
<string>Enter the name of the application you want to run or the URL you want to view</string>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter</set>
</property>
</widget>
@@ -636,8 +636,8 @@
<include location="local" impldecl="in implementation">kpushbutton.h</include>
</includes>
<pixmapfunction>BarIcon</pixmapfunction>
-<tqlayoutdefaults spacing="3" margin="6"/>
-<tqlayoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
+<layoutdefaults spacing="3" margin="6"/>
+<layoutfunctions spacing="KDialog::spacingHint" margin="KDialog::marginHint"/>
<includehints>
<includehint>kpushbutton.h</includehint>
<includehint>kpushbutton.h</includehint>
diff --git a/kdesktop/pixmapserver.cc b/kdesktop/pixmapserver.cc
index 30da39f01..bc869d341 100644
--- a/kdesktop/pixmapserver.cc
+++ b/kdesktop/pixmapserver.cc
@@ -58,7 +58,7 @@ KPixmapServer::~KPixmapServer()
void KPixmapServer::add(TQString name, TQPixmap *pm, bool overwrite)
{
- if (m_Names.tqcontains(name))
+ if (m_Names.contains(name))
{
if (overwrite)
remove(name);
@@ -174,7 +174,7 @@ bool KPixmapServer::x11Event(XEvent *event)
}
// Check if there is no transaction in progress to the same property
- if (m_Active.tqcontains(ev->property))
+ if (m_Active.contains(ev->property))
{
kdDebug(1204) << ID << "selection is busy.\n";
XSendEvent(qt_xdisplay(), ev->requestor, false, 0, &reply);
diff --git a/kdesktop/programs/xplanet.desktop b/kdesktop/programs/xplanet.desktop
index db0df2c47..5590a53e0 100644
--- a/kdesktop/programs/xplanet.desktop
+++ b/kdesktop/programs/xplanet.desktop
@@ -1,5 +1,5 @@
[KDE Desktop Program]
-Command=xplanet --tqgeometry %xx%y --num_times 1 --output %f.jpg && mv %f.jpg %f
+Command=xplanet --geometry %xx%y --num_times 1 --output %f.jpg && mv %f.jpg %f
Comment=XPlanet by Hari Nair
Comment[af]=XPlaneet deur Hari Nair
Comment[ar]=XPlanet من تليف Hari Nair
@@ -76,5 +76,5 @@ Comment[zh_CN]=Hari Nair 的 XPlanet
Comment[zh_TW]=XPlanet (Hari Nair 繪製)
Comment[zu]=XPlanet ngu-Hari Nair
Executable=xplanet
-PreviewCommand=xplanet --tqgeometry %xx%y --num_times 1 --output %f.jpg && mv %f.jpg %f
+PreviewCommand=xplanet --geometry %xx%y --num_times 1 --output %f.jpg && mv %f.jpg %f
Refresh=10
diff --git a/kdesktop/startupid.cpp b/kdesktop/startupid.cpp
index d8c9be53f..720dd4bba 100644
--- a/kdesktop/startupid.cpp
+++ b/kdesktop/startupid.cpp
@@ -82,7 +82,7 @@ void StartupId::configure()
void StartupId::gotNewStartup( const KStartupInfoId& id_P, const KStartupInfoData& data_P )
{
- TQString icon = data_P.tqfindIcon();
+ TQString icon = data_P.findIcon();
current_startup = id_P;
startups[ id_P ] = icon;
start_startupid( icon );
@@ -92,7 +92,7 @@ void StartupId::gotStartupChange( const KStartupInfoId& id_P, const KStartupInfo
{
if( current_startup == id_P )
{
- TQString icon = data_P.tqfindIcon();
+ TQString icon = data_P.findIcon();
if( !icon.isEmpty() && icon != startups[ current_startup ] )
{
startups[ id_P ] = icon;
@@ -218,8 +218,8 @@ void StartupId::start_startupid( const TQString& icon_P )
}
else
{
- if( icon_pixmap.tqmask() != NULL )
- startup_widget->setMask( *icon_pixmap.tqmask());
+ if( icon_pixmap.mask() != NULL )
+ startup_widget->setMask( *icon_pixmap.mask());
else
startup_widget->clearMask();
startup_widget->setBackgroundPixmap( icon_pixmap );
@@ -257,8 +257,8 @@ void StartupId::update_startupid()
yoffset = frame_to_yoffset[ frame ];
TQPixmap pm = pixmaps[ frame_to_pixmap[ frame ] ];
startup_widget->setBackgroundPixmap( pm );
- if ( pm.tqmask() != NULL )
- startup_widget->setMask( *pm.tqmask() );
+ if ( pm.mask() != NULL )
+ startup_widget->setMask( *pm.mask() );
else
startup_widget->clearMask();
if ( ++frame >= ( sizeof( frame_to_yoffset ) / sizeof( frame_to_yoffset[ 0 ] ) ) )
diff --git a/kdesktop/xautolock.cc b/kdesktop/xautolock.cc
index 40f26e58a..b69325f17 100644
--- a/kdesktop/xautolock.cc
+++ b/kdesktop/xautolock.cc
@@ -32,7 +32,7 @@ extern "C" {
#include <X11/extensions/dpms.h>
#ifndef HAVE_DPMSINFO_PROTO
-tqStatus DPMSInfo ( Display *, CARD16 *, BOOL * );
+Status DPMSInfo ( Display *, CARD16 *, BOOL * );
#endif
}
#endif
diff --git a/kdesktop/xautolock_diy.c b/kdesktop/xautolock_diy.c
index 52a4254d5..b9df2f895 100644
--- a/kdesktop/xautolock_diy.c
+++ b/kdesktop/xautolock_diy.c
@@ -115,7 +115,7 @@ selectEvents (Window window, Bool substructureOnly)
if (nofChildren) (void) XFree ((char*) children);
/*
- * Build the appropriate event tqmask. The basic idea is that we don't
+ * Build the appropriate event mask. The basic idea is that we don't
* want to interfere with the normal event propagation mechanism if
* we don't have to.
*
@@ -134,8 +134,8 @@ selectEvents (Window window, Bool substructureOnly)
{
if (parent == None) /* the *real* rootwindow */
{
- attribs.all_event_tqmasks =
- attribs.do_not_propagate_tqmask = KeyPressMask;
+ attribs.all_event_masks =
+ attribs.do_not_propagate_mask = KeyPressMask;
}
else if (!XGetWindowAttributes (queue.display, window, &attribs))
#else
@@ -149,19 +149,19 @@ selectEvents (Window window, Bool substructureOnly)
#if 0
(void) XSelectInput (queue.display, window,
SubstructureNotifyMask
- | ( ( attribs.all_event_tqmasks
- | attribs.do_not_propagate_tqmask)
+ | ( ( attribs.all_event_masks
+ | attribs.do_not_propagate_mask)
& KeyPressMask));
#else
{
- int tqmask = SubstructureNotifyMask | attribs.your_event_mask;
+ int mask = SubstructureNotifyMask | attribs.your_event_mask;
if( !substructureOnly )
{
- tqmask |= ( ( attribs.all_event_masks
+ mask |= ( ( attribs.all_event_masks
| attribs.do_not_propagate_mask)
& KeyPressMask );
}
- (void) XSelectInput (queue.display, window, tqmask );
+ (void) XSelectInput (queue.display, window, mask );
}
#endif
diff --git a/kdesktop/xautolock_engine.c b/kdesktop/xautolock_engine.c
index 64c542bfb..1825b7fe2 100644
--- a/kdesktop/xautolock_engine.c
+++ b/kdesktop/xautolock_engine.c
@@ -74,7 +74,7 @@ xautolock_queryPointer (Display* d)
{
Window dummyWin; /* as it says */
int dummyInt; /* as it says */
- unsigned tqmask; /* modifier tqmask */
+ unsigned mask; /* modifier mask */
int rootX; /* as it says */
int rootY; /* as it says */
int corner; /* corner index */
@@ -104,7 +104,7 @@ xautolock_queryPointer (Display* d)
* of pointer events.
*/
if (!XQueryPointer (d, root, &root, &dummyWin, &rootX, &rootY,
- &dummyInt, &dummyInt, &tqmask))
+ &dummyInt, &dummyInt, &mask))
{
/*
* Pointer has moved to another screen, so let's find out which one.
@@ -121,7 +121,7 @@ xautolock_queryPointer (Display* d)
if ( rootX == prevRootX
&& rootY == prevRootY
- && tqmask == prevMask)
+ && mask == prevMask)
{
xautolock_corner_t* corners = xautolock_corners;
/*
@@ -186,7 +186,7 @@ xautolock_queryPointer (Display* d)
#endif
prevRootX = rootX;
prevRootY = rootY;
- prevMask = tqmask;
+ prevMask = mask;
xautolock_resetTriggers ();
}
@@ -224,7 +224,7 @@ evaluateTriggers (Display* d)
* when we are finally re-enabled.
*/
#ifdef VMS
- if (vmstqStatus == 0)
+ if (vmsStatus == 0)
{
#else /* VMS */
if (lockerPid)
@@ -336,7 +336,7 @@ evaluateTriggers (Display* d)
|| now >= lockTrigger)
{
#ifdef VMS
- if (vmstqStatus != 0)
+ if (vmsStatus != 0)
#else /* VMS */
if (!lockerPid)
#endif /* VMS */
@@ -350,9 +350,9 @@ evaluateTriggers (Display* d)
case 0:
(void) close (ConnectionNumber (d));
#ifdef VMS
- vmstqStatus = 0;
+ vmsStatus = 0;
lockerPid = lib$spawn ((lockNow ? &nowLockerDescr : &lockerDescr),
- 0, 0, &1, 0, 0, &vmstqStatus);
+ 0, 0, &1, 0, 0, &vmsStatus);
if (!(lockerPid & 1)) exit (lockerPid);
@@ -380,7 +380,7 @@ evaluateTriggers (Display* d)
* Nevertheless, simply resetting the screensaver is a
* convenience action that aids many xlock users, and doesn't
* harm anyone (*). The problem with older versions of xlock
- * is that they can be told to tqreplace (= disable) the real
+ * is that they can be told to replace (= disable) the real
* screensaver, but forget to reset that same screensaver if
* it was already active at the time xlock starts. I guess
* xlock initially wasn't designed to be run without a user
diff --git a/kdesktop/bgmanager.cc b/kdesktop/bgmanager.cc
index 3c81e26db..6d106a484 100644
--- a/kdesktop/bgmanager.cc
+++ b/kdesktop/bgmanager.cc
@@ -334,7 +334,7 @@ void KBackgroundManager::slotChangeNumberOfDesktops(int num)
/*
* Call this when the desktop has been changed.
* Desk is in KWin convention: [1..desks], instead of [0..desks-1].
- * 0 tqrepaints the current desktop.
+ * 0 repaints the current desktop.
*/
void KBackgroundManager::slotChangeDesktop(int desk)
{
@@ -394,7 +394,7 @@ void KBackgroundManager::slotChangeDesktop(int desk)
/*
* Call this when the viewport has been changed.
* Desk is in KWin convention: [1..desks], instead of [0..desks-1].
- * 0 tqrepaints the current viewport.
+ * 0 repaints the current viewport.
*/
void KBackgroundManager::slotChangeViewport(int desk, const TQPoint& viewport)
{
@@ -518,11 +518,11 @@ void KBackgroundManager::setPixmap(KPixmap *pm, int hash, int desk)
{
TQScrollView* sv = dynamic_cast<TQScrollView*>( m_pDesktop );
if ( sv ) {
// Qt eats tqrepaint events in this case :-((
sv->viewport()->update();
}
m_pDesktop->setErasePixmap(*ep);
- m_pDesktop->tqrepaint();
+ m_pDesktop->repaint();
static bool root_cleared = false;
if( !root_cleared )
{ // clear the root window pixmap set by kdm
@@ -920,10 +920,10 @@ void KBackgroundManager::setWallpaper(int desk, TQString wallpaper, int mode)
slotChangeDesktop(sdesk);
}
-void KBackgroundManager::tqrepaintBackground()
+void KBackgroundManager::repaintBackground()
{
if (m_pDesktop)
- m_pDesktop->tqrepaint();
+ m_pDesktop->repaint();
else
KApplication::desktop()->screen()->erase();
}
@@ -952,10 +952,10 @@ void KBackgroundManager::desktopResized()
m_Hash = 0;
if( m_pDesktop )
- m_pDesktop->resize( kapp->desktop()->tqgeometry().size());
+ m_pDesktop->resize( kapp->desktop()->geometry().size());
// Repaint desktop
slotChangeDesktop(0);
- tqrepaintBackground();
+ repaintBackground();
// Redraw all desktops so that applications relying on exported data, e.g. kpager, continue to work properly
TQSize s(m_pKwinmodule->numberOfViewports(m_pKwinmodule->currentDesktop()));
@@ -518,11 +518,11 @@ void KBackgroundManager::setPixmap(KPixmap *pm, int hash, int desk)
TQScrollView* sv = dynamic_cast<TQScrollView*>( m_pDesktop );
if ( sv ) {
- // Qt eats tqrepaint events in this case :-((
+ // Qt eats repaint events in this case :-((
sv->viewport()->update();
}
diff --git a/kdesktop/kcustommenu.cc b/kdesktop/kcustommenu.cc
index 2a6b64ec6..1d39a093d 100644
--- a/kdesktop/kcustommenu.cc
+++ b/kdesktop/kcustommenu.cc
@@ -81,8 +81,8 @@ KCustomMenu::insertMenuItem(KService::Ptr & s, int nId, int nIndex/*= -1*/)
TQString serviceName = s->name();
// item names may contain ampersands. To avoid them being converted
- // to accelators, tqreplace them with two ampersands.
- serviceName.tqreplace("&", "&&");
+ // to accelators, replace them with two ampersands.
+ serviceName.replace("&", "&&");
TQPixmap normal = KGlobal::instance()->iconLoader()->loadIcon(s->icon(), KIcon::Small,
0, KIcon::DefaultState, 0L, true);
diff --git a/kdesktop/kdiconview.cc b/kdesktop/kdiconview.cc
index 3c7611be4..5d20aa12d 100644
--- a/kdesktop/kdiconview.cc
+++ b/kdesktop/kdiconview.cc
@@ -67,7 +67,7 @@ extern int kdesktop_screen_number;
TQRect KDIconView::desktopRect()
{
return ( kdesktop_screen_number == 0 )
- ? TQApplication::desktop()->tqgeometry() // simple case, or xinerama
+ ? TQApplication::desktop()->geometry() // simple case, or xinerama
: TQApplication::desktop()->screenGeometry( kdesktop_screen_number ); // multi-head
}
@@ -296,7 +296,7 @@ void KDIconView::initConfig( bool init )
m_bSortDirectoriesFirst = KDesktopSettings::directoriesFirst();
m_itemsAlwaysFirst = KDesktopSettings::alwaysFirstItems(); // Distributor plug-in
- if (KProtocolInfo::isKnownProtocol(TQString::tqfromLatin1("media")))
+ if (KProtocolInfo::isKnownProtocol(TQString::fromLatin1("media")))
m_enableMedia=KDesktopSettings::mediaEnabled();
else
m_enableMedia=false;
@@ -321,7 +321,7 @@ void KDIconView::initConfig( bool init )
if ( previewSettings().count() )
{
for ( TQStringList::ConstIterator it = oldPreview.begin(); it != oldPreview.end(); ++it)
- if ( !previewSettings().tqcontains( *it ) ){
+ if ( !previewSettings().contains( *it ) ){
kdDebug(1204) << "Disabling preview for " << *it << endl;
if ( *it == "audio/" )
disableSoundPreviews();
@@ -581,7 +581,7 @@ KURL KDIconView::desktopURL()
if (kdesktop_screen_number != 0) {
TQString dn = "Desktop";
dn += TQString::number(kdesktop_screen_number);
- desktopPath.tqreplace("Desktop", dn);
+ desktopPath.replace("Desktop", dn);
}
KURL desktopURL;
@@ -748,7 +748,7 @@ void KDIconView::fillMediaListView()
for (; it2 != mimetypes.end(); ++it2) {
if ( ((*it2)->name().startsWith("media/")) )
{
- bool ok=excludedMedia.tqcontains((*it2)->name())==0;
+ bool ok=excludedMedia.contains((*it2)->name())==0;
new DesktopBehaviorMediaItem (mMediaListView, (*it2)->comment(), (*it2)->name(),ok);
}
}
@@ -960,20 +960,20 @@ bool KDIconView::isDesktopFile( KFileItem * _item ) const
return false;
// return true if desktop file
- return ( (_item->mimetype() == TQString::tqfromLatin1("application/x-desktop"))
- || (_item->mimetype() == TQString::tqfromLatin1("media/builtin-mydocuments"))
- || (_item->mimetype() == TQString::tqfromLatin1("media/builtin-mycomputer"))
- || (_item->mimetype() == TQString::tqfromLatin1("media/builtin-mynetworkplaces"))
- || (_item->mimetype() == TQString::tqfromLatin1("media/builtin-printers"))
- || (_item->mimetype() == TQString::tqfromLatin1("media/builtin-trash"))
- || (_item->mimetype() == TQString::tqfromLatin1("media/builtin-webbrowser")) );
+ return ( (_item->mimetype() == TQString::fromLatin1("application/x-desktop"))
+ || (_item->mimetype() == TQString::fromLatin1("media/builtin-mydocuments"))
+ || (_item->mimetype() == TQString::fromLatin1("media/builtin-mycomputer"))
+ || (_item->mimetype() == TQString::fromLatin1("media/builtin-mynetworkplaces"))
+ || (_item->mimetype() == TQString::fromLatin1("media/builtin-printers"))
+ || (_item->mimetype() == TQString::fromLatin1("media/builtin-trash"))
+ || (_item->mimetype() == TQString::fromLatin1("media/builtin-webbrowser")) );
}
TQString KDIconView::stripDesktopExtension( const TQString & text )
{
- if (text.right(7) == TQString::tqfromLatin1(".kdelnk"))
+ if (text.right(7) == TQString::fromLatin1(".kdelnk"))
return text.left(text.length() - 7);
- else if (text.right(8) == TQString::tqfromLatin1(".desktop"))
+ else if (text.right(8) == TQString::fromLatin1(".desktop"))
return text.left(text.length() - 8);
return text;
}
@@ -1009,12 +1009,12 @@ bool KDIconView::makeFriendlyText( KFileIVI *fileIVI )
TQStringList tmpList;
if (cfg.hasKey("OnlyShowIn"))
{
- if (!cfg.readListEntry("OnlyShowIn", ';').tqcontains("KDE"))
+ if (!cfg.readListEntry("OnlyShowIn", ';').contains("KDE"))
return false;
}
if (cfg.hasKey("NotShowIn"))
{
- if (cfg.readListEntry("NotShowIn", ';').tqcontains("KDE"))
+ if (cfg.readListEntry("NotShowIn", ';').contains("KDE"))
return false;
}
if (cfg.hasKey("TryExec"))
@@ -1055,7 +1055,7 @@ void KDIconView::slotNewItems( const KFileItemList & entries )
KURL desktop_URL = desktopURL();
if (desktop_URL.isLocalFile())
desktopPath = desktop_URL.path();
// We have new items, so we'll need to tqrepaint in slotCompleted
m_bNeedRepaint = true;
kdDebug(1214) << "KDIconView::slotNewItems count=" << entries.count() << endl;
KFileItemListIterator it(entries);
@@ -1198,7 +1198,7 @@ void KDIconView::slotRefreshItems( const KFileItemList & entries )
}
else
{
// In case we tqreplace a big icon with a small one, need to tqrepaint.
updateContents();
// Can't do that with m_bNeedRepaint since slotCompleted isn't called
m_bNeedRepaint = false;
@@ -1305,7 +1305,7 @@ void KDIconView::slotCompleted()
if (!m_hasExistingPos)
rearrangeIcons();
-// kdDebug(1204) << "KDIconView::slotCompleted save:" << m_bNeedSave << " tqrepaint:" << m_bNeedRepaint << endl;
+// kdDebug(1204) << "KDIconView::slotCompleted save:" << m_bNeedSave << " repaint:" << m_bNeedRepaint << endl;
if ( m_bNeedSave )
{
// Done here because we want to align icons only once initially, and each time new icons appear.
@@ -1317,7 +1317,7 @@ void KDIconView::slotCompleted()
}
if ( m_bNeedRepaint )
{
- viewport()->tqrepaint();
+ viewport()->repaint();
m_bNeedRepaint = false;
}
}
@@ -1463,7 +1463,7 @@ void KDIconView::contentsDropEvent( TQDropEvent * e )
{
kdDebug(1204)<<"void KDIconView::contentsDropEvent( TQDropEvent * e )\n";
// mind: if it's a filedrag which itself is an image, libkonq is called. There's a popup for drops as well
// that tqcontains the same line "Set as Wallpaper" in void KonqOperations::asyncDrop
bool isColorDrag = KColorDrag::canDecode(e);
bool isImageDrag = TQImageDrag::canDecode(e);
bool isUrlDrag = KURLDrag::canDecode(e);
@@ -1471,7 +1471,7 @@ void KDIconView::contentsDropEvent( TQDropEvent * e )
bool isImmutable = KGlobal::config()->isImmutable();
if ( (isColorDrag || isImageDrag) && !isUrlDrag ) {
- // Hack to clear the drag tqshape
+ // Hack to clear the drag shape
bool bMovable = itemsMovable();
bool bSignals = signalsBlocked();
setItemsMovable(false);
@@ -1499,7 +1499,7 @@ void KDIconView::contentsDropEvent( TQDropEvent * e )
bool adjustedAnyItems = false;
for( TQIconViewItem *item = firstItem(); item; item = item->nextItem() )
{
- if( !desk.tqcontains( item->rect(), true ))
+ if( !desk.contains( item->rect(), true ))
{
TQRect r = item->rect();
@@ -1519,7 +1519,7 @@ void KDIconView::contentsDropEvent( TQDropEvent * e )
if( adjustedAnyItems )
{
// Make sure the viewport isn't unnecessarily resized by now,
// then schedule a tqrepaint to remove any garbage pixels.
resizeContents( width(), height() );
viewport()->update();
}
@@ -1541,7 +1541,7 @@ void KDIconView::updateWorkArea( const TQRect &wr )
{
m_gotIconsArea = true; // now we have it!
- if (( iconArea() == wr ) && (m_needDesktopAlign == false)) return; // nothing changed; avoid tqrepaint/saveIconPosition ...
+ if (( iconArea() == wr ) && (m_needDesktopAlign == false)) return; // nothing changed; avoid repaint/saveIconPosition ...
TQRect oldArea = iconArea();
setIconArea( wr );
@@ -1593,8 +1593,8 @@ void KDIconView::updateWorkArea( const TQRect &wr )
}
}
if ( needRepaint ) {
- viewport()->tqrepaint( FALSE );
- tqrepaint( FALSE );
+ viewport()->repaint( FALSE );
+ repaint( FALSE );
saveIconPositions();
}
}
@@ -1718,7 +1718,7 @@ void KDIconView::moveToFreePosition(TQIconViewItem *item )
TQRect rect=item->rect();
if (m_bVertAlign)
{
- kdDebug(1214)<<"moveToFreePosition for vertical tqalignment"<<endl;
+ kdDebug(1214)<<"moveToFreePosition for vertical alignment"<<endl;
rect.moveTopLeft(TQPoint(spacing(),spacing()));
do
@@ -1055,7 +1055,7 @@ void KDIconView::slotNewItems( const KFileItemList & entries )
if (desktop_URL.isLocalFile())
desktopPath = desktop_URL.path();
- // We have new items, so we'll need to tqrepaint in slotCompleted
+ // We have new items, so we'll need to repaint in slotCompleted
m_bNeedRepaint = true;
kdDebug(1214) << "KDIconView::slotNewItems count=" << entries.count() << endl;
@@ -1198,7 +1198,7 @@ void KDIconView::slotRefreshItems( const KFileItemList & entries )
else
{
- // In case we tqreplace a big icon with a small one, need to tqrepaint.
+ // In case we replace a big icon with a small one, need to repaint.
updateContents();
// Can't do that with m_bNeedRepaint since slotCompleted isn't called
@@ -1463,7 +1463,7 @@ void KDIconView::contentsDropEvent( TQDropEvent * e )
kdDebug(1204)<<"void KDIconView::contentsDropEvent( TQDropEvent * e )\n";
// mind: if it's a filedrag which itself is an image, libkonq is called. There's a popup for drops as well
- // that tqcontains the same line "Set as Wallpaper" in void KonqOperations::asyncDrop
+ // that contains the same line "Set as Wallpaper" in void KonqOperations::asyncDrop
bool isColorDrag = KColorDrag::canDecode(e);
bool isImageDrag = TQImageDrag::canDecode(e);
@@ -1519,7 +1519,7 @@ void KDIconView::contentsDropEvent( TQDropEvent * e )
{
// Make sure the viewport isn't unnecessarily resized by now,
- // then schedule a tqrepaint to remove any garbage pixels.
+ // then schedule a repaint to remove any garbage pixels.
resizeContents( width(), height() );
viewport()->update();